---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: cuihantao

---

**Describe the bug**

A clear and concise description of what the bug is.

**To Reproduce**

Update data files and code for reproducing the error.

If you need to insert code inline, use a pair of triple backticks to format:

    ```python
    Code goes here
    ```

**Expected behavior**

A clear and concise description of what you expected to happen.

**Desktop (please complete the following information):**

 - OS: [e.g. Windows]
 - ANDES version (please paste the output from `andes misc --version`)


**pip packages (please paste the output from `pip list`)


**Additional context**

Add any other context about the problem here.
